#!/usr/bin/bash

set -e -u

SPEC="python-watchfiles.spec"

MACROS="$(grep -E '^%global' "${SPEC}" | grep -vE '%\{[a-z]+:$')"
get_macro()
{
  rpm -E "${MACROS}
%{${1}}"
}

URL="$(get_macro notify_url)"
REV="$(get_macro notify_rev)"
VERSION="$(get_macro notify_baseversion)"
TYPES_VERSION="$(get_macro notify_types_baseversion)"
SNAPDATE="$(get_macro notify_snapdate)"

OUTDIR="${PWD}"
TMPDIR="$(mktemp -d)"
trap "rm -rf '${TMPDIR}'" INT TERM EXIT
ROOTDIR="${TMPDIR}/notify-${REV}"
mkdir "${ROOTDIR}"

# download and extract the GitHub source archive
ARCHIVE_URL="${URL}/archive/${REV}/notify-${REV}.tar.gz"
pushd "${TMPDIR}"
curl -L -O "${ARCHIVE_URL}"
tar -xzf "notify-${REV}.tar.gz"
rm "notify-${REV}.tar.gz"
popd

pushd "${ROOTDIR}"

# Fix the workspace dependency on notify-types (which is a path dependency) to
# be a versioned dependency so that we can successfully package crates.
tomcli set Cargo.toml str workspace.dependencies.notify-types \
    "$(tomcli get notify-types/Cargo.toml package.version)"

# Remove workspace crates other than notify, notify-types, tests, and examples,
# to help prove they (and their various licenses) do not contribute to the
# notify and notify-types crates:
find . -mindepth 1 -maxdepth 1 -type d \
    ! \( -name notify -o -name notify-types \) \
    -execdir rm -rv '{}' '+'
# Adjust the workspace members accordingly:
tomcli set Cargo.toml list workspace.members notify notify-types

pushd notify-types
# repackage crate
cargo package --allow-dirty
popd

pushd notify
# repackage crate
cargo package --allow-dirty
popd

# move repackaged crates
SNAPINFO="${SNAPDATE}git$(echo "${REV}" | cut -b -7)"
mv "target/package/notify-types-${TYPES_VERSION}.crate" \
    "${OUTDIR}/notify-types-${TYPES_VERSION}^${SNAPINFO}.crate"
mv "target/package/notify-${VERSION}.crate" \
    "${OUTDIR}/notify-${VERSION}^${SNAPINFO}.crate"

popd
